@@ -7,36 +7,24 @@ from termcolor import cprint
 from libs import datalib
 
 
-@click.group()
-def main():
-    pass
-
-
 def print_version(ctx, param, value):
     if not value or ctx.resilient_parsing:
         return
-    click.echo(cprint(figlet_format("TerraMagic", font="slant"), "magenta"))
-    click.echo(
-
-        "TerraMagic-cli is a tool for creating a structure of folders and files for Terraform"
-    )
+    click.echo(cprint(figlet_format("TerraMagic"), "magenta"))
+    click.echo("TerraMagic is a tool for creating a structure of folders and files for Terraform")
     click.echo("Author: https://github.com/miltlima")
-    click.echo("Version: 0.0.2")
+    click.echo("Version: 0.0.6")
     ctx.exit()
 
+@click.group()
+@click.option("--version", "-v", is_flag=True, callback=print_version,expose_value=False,is_eager=True,help="Show version")
+def main():
+    pass
+
 
 @main.command()
 @click.option("--name", "-n", help="Name of the project")
 @click.option("--env", "-e", help="Environment name(dev, test, prd)", multiple=True)
-@click.option(
-    "--version",
-    "-v",
-    is_flag=True,
-    callback=print_version,
-    expose_value=False,
-    is_eager=True,
-    help="Show version",
-)
 def create_project(name, env):
     try:
         os.mkdir(name)
@@ -49,19 +37,17 @@ def create_project(name, env):
                 for file in datalib.files:
                     open(file, "w+")
                 os.chdir("..")
-            click.echo(
-                click.style(
-                    (f"Created project {name} successfully, You're ready move to ☁️ !!"),
-                    fg="green",
-                )
-            )
+            click.secho(
+                (f"Created project {name} successfully, You're ready move to ☁️ !!"),fg="green",)
+
         else:
-            click.echo(click.style((f"Environment {env} not found"), fg="red"))
+            click.secho((f"Environment {env} not found"), fg="red")
 
     except FileExistsError:
-        click.echo(click.style(("The directory already exists!"), bg="red"))
+        click.secho(("The directory already exists!"), bg="red")
         os.chdir("..")
 
+main.add_command(create_project)
 
 if __name__ == "__main__":
     main()
